==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/RuleManagementEventClaimsDataSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The claims for a rule management event data source.
 * @property emailAddress the email address.
 */
public data class RuleManagementEventClaimsDataSourceArgs(
    public val emailAddress: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs> {
    override fun toJava():
        com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs =
        com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs.builder()
            .emailAddress(emailAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleManagementEventClaimsDataSourceArgs].
 */
@PulumiTagMarker
public class RuleManagementEventClaimsDataSourceArgsBuilder internal constructor() {
    private var emailAddress: Output<String>? = null

    /**
     * @param value the email address.
     */
    @JvmName("xhnebgkwhmabnuvq")
    public suspend fun emailAddress(`value`: Output<String>) {
        this.emailAddress = value
    }

    /**
     * @param value the email address.
     */
    @JvmName("rcnufvdcenlviiyk")
    public suspend fun emailAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailAddress = mapped
    }

    internal fun build(): RuleManagementEventClaimsDataSourceArgs =
        RuleManagementEventClaimsDataSourceArgs(
            emailAddress = emailAddress,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/RuleManagementEventClaimsDataSourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The claims for a rule management event data source.
 * @property emailAddress the email address.
 */
public data class RuleManagementEventClaimsDataSourceArgs(
    public val emailAddress: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs> {
    override fun toJava():
        com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs =
        com.pulumi.azurenative.insights.inputs.RuleManagementEventClaimsDataSourceArgs.builder()
            .emailAddress(emailAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [RuleManagementEventClaimsDataSourceArgs].
 */
@PulumiTagMarker
public class RuleManagementEventClaimsDataSourceArgsBuilder internal constructor() {
    private var emailAddress: Output<String>? = null

    /**
     * @param value the email address.
     */
    @JvmName("nuyewckchupujggx")
    public suspend fun emailAddress(`value`: Output<String>) {
        this.emailAddress = value
    }

    /**
     * @param value the email address.
     */
    @JvmName("hmsbvdrryfdbpehm")
    public suspend fun emailAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailAddress = mapped
    }

    internal fun build(): RuleManagementEventClaimsDataSourceArgs =
        RuleManagementEventClaimsDataSourceArgs(
            emailAddress = emailAddress,
        )
}
